@@ -31,12 +31,12 @@ dimnames(tab) = list(levels(donnee[,col.p]),levels(donnee[,col.j]),labels(donnee
 
 for (k in 1:dim(tab)[[3]]){
   plotinteract(tab[,,k],main=colnames(donnee)[firstvar+k-1],xlab=colnames(donnee)[col.j],ylab=paste(colnames(donnee)[col.p],"-",colnames(donnee)[col.j],"interaction coefficients"))
-  if (k != dim(tab)[[3]]) dev.new()
+  if ((k != dim(tab)[[3]])&(!nzchar(Sys.getenv("RSTUDIO_USER_IDENTITY")))) dev.new()
 }
 barrow(t(apply(tab^2,c(1,3),sum)/matrix(rep(apply(tab^2,3,sum),nrow(tab)),byrow=TRUE,nrow=nrow(tab))),color="orange")
 
 ## Make a graph to visualize the panelist which contribute the product-panelist interaction for each descriptor
 barrow(t(  apply(tab^2,c(2,3),sum) /matrix(rep(apply(tab^2,3,sum),ncol(tab)),byrow=TRUE,nrow=ncol(tab))))
-return(tab)
 options(contrasts=old.contr)
+return(tab)
 }
